References
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. [Christiansen1974] Christiansen, Freddy Bugge. 1974. “Sufficient Conditions for Protected Polymorphism in a Subdivided Population.” The American Naturalist 108 (960): 157–66.

.. [Christiansen1975] Christiansen, Freddy Bugge. 1975. “Hard and Soft Selection in a Subdivided Population.” The American Naturalist 109 (965): 11–16.

.. [Felsenstein1976] Felsenstein, J. 1976. “The Theoretical Population Genetics of Variable Selection and Migration.” Annual Review of Genetics 10: 253–80.

.. [Jouganous2017] Jouganous, Julien, Will Long, Aaron P. Ragsdale, and Simon Gravel. 2017. “Inferring the Joint Demographic History of Multiple Populations: Beyond the Diffusion Approximation.” Genetics 206 (3): 1549–67.

.. [Kelleher2016] Kelleher, Jerome, Alison M. Etheridge, and Gilean McVean. 2016. “Efficient Coalescent Simulation and Genealogical Analysis for Large Sample Sizes.” PLoS Computational Biology 12 (5): e1004842.

.. [Kelleher2018] Kelleher, Jerome, Kevin R. Thornton, Jaime Ashander, and Peter L. Ralph. 2018. “Efficient Pedigree Recording for Fast Population Genetics Simulation.” PLoS Computational Biology 14 (11): e1006581.

.. [Levene1953] Levene, Howard. 1953. “Genetic Equilibrium When More Than One Ecological Niche Is Available.” The American Naturalist 87 (836): 331–33.

